<?php
/**
 * LyftenBloggie 1.0 - Joomla! Blog Manager
 * @package LyftenBloggie 1.0
 * @copyright (C) 2009 Lyften Designs
 * @license http://www.gnu.org/copyleft/gpl.html GNU/GPL
 * @link http://www.lyften.com/ Official website
 **/
 
// Disallow direct access to this file
defined('_JEXEC') or die('Restricted access');

jimport('joomla.application.component.model');

/**
 * @package Joomla
 * @subpackage LyftenBloggie
 * @since 1.0
 */
class LyftenBloggieModelAuthor extends JModel
{

	var $_author = null;

	/**
	 * Constructor
	 **/
	function __construct()
	{
		parent::__construct();

		$array = JRequest::getVar('cid',  0, '', 'array');
		$this->setId((int)$array[0]);
	}

	/**
	 * Method to set the identifier
	 **/
	function setId($id)
	{
		// Set author id and wipe data
		$this->_id	    	= $id;
		$this->_author	= null;
	}
	
	/**
	 * Overridden get method to get properties from the author
	 **/
	function get($property, $default=null)
	{
		if ($this->_loadAuthor()) {
			if(isset($this->_author->$property)) {
				return $this->_author->$property;
			}
		}
		return $default;
	}

	/**
	 * Method to get author data
	 **/
	function &getAuthor()
	{
		if ($this->_loadAuthor())
		{

		}
		else  $this->_initAuthor();

		return $this->_author;
	}

	/**
	 * Method to load author data
	 **/
	function _loadAuthor()
	{
		// Lets load the author if it doesn't already exist
		if (empty($this->_author))
		{
			$query = 'SELECT a.*, u.username'
					. ' FROM #__bloggies_authors as a'
					. ' LEFT JOIN #__users AS u ON u.id = a.user_id'	
					. ' WHERE a.id = '.$this->_id
					;
			$this->_db->setQuery($query);
			$this->_author = $this->_db->loadObject();

			return (boolean) $this->_author;
		}
		return true;
	}
	
	/**
	 * Method to get a list of Joomla Users
	 **/
	function getUsers()
	{
		$query = 'SELECT u.name, u.id'
				. ' FROM #__users as u'
				. ' LEFT OUTER JOIN #__bloggies_authors AS a ON a.user_id = u.id'
				;
		$this->_db->setQuery($query);
	
		$users[] 	= JHTML::_('select.option', '0', ' - '.JText::_('SELECT USER').' - ', 'id', 'name');
		$users 		= array_merge($users, $this->_db->loadObjectList());
		$users 		= JHTML::_('select.genericlist',  $users, 'user_id', 'class="inputbox" size="1"', 'id', 'name', $this->_author->id);	

		return $users;
	}

	/**
	 * Method to initialise the author data
	 **/
	function _initAuthor()
	{
		// Lets load the author if it doesn't already exist
		if (empty($this->_author))
		{
			$author = new stdClass();
			$author->id					= 0;
			$author->user_id			= null;
			$author->name				= null;
			$author->about				= null;
			$author->permission			= null;
			$author->avatar				= null;
			$author->attribs			= null;
			$author->published			= 1;
			$this->_author				= $author;
			return (boolean) $this->_author;
		}
		return true;
	}

	/**
	 * Method to checkin/unlock the author
	 **/
	function checkin()
	{
		if ($this->_id)
		{
			$author = & JTable::getInstance('authors', 'Table');
			return $author->checkin($this->_id);
		}
		return false;
	}

	/**
	 * Method to checkout/lock the author
	 **/
	function checkout($uid = null)
	{
		if ($this->_id)
		{
			// Make sure we have a user id to checkout the author with
			if (is_null($uid)) {
				$user	=& JFactory::getUser();
				$uid	= $user->get('id');
			}
			// Lets get to it and checkout the thing...
			$author = & JTable::getInstance('authors', 'Table');
			if(!$author->checkout($uid, $this->_id)) {
				$this->setError($this->_db->getErrorMsg());
				return false;
			}

			return true;
		}
		return false;
	}

	/**
	 * Tests if the author is checked out
	 **/
	function isCheckedOut( $uid=0 )
	{
		if ($this->_loadAuthor())
		{
			if ($uid) {
				return ($this->_author->checked_out && $this->_author->checked_out != $uid);
			} else {
				return $this->_author->checked_out;
			}
		} elseif ($this->_id < 1) {
			return false;
		} else {
			JError::raiseWarning( 0, 'UNABLE LOAD DATA');
			return false;
		}
	}

	/**
	 * Method to store the author
	 **/
	function store($data)
	{
		$author  =& $this->getTable('authors', 'Table');

		// bind it to the table
		if (!$author->bind($data)) {
			$this->setError(500, $this->_db->getErrorMsg() );
			return false;
		}

		if (isset( $_FILES['avatar']) and !$_FILES['avatar']['error'] ) {

			//Get the blog author helper
			require_once( JPATH_COMPONENT.DS.'helper.php' );
			$user = & JFactory::getUser();
			$author->avatar = BlogAuthor::createAvatar($_FILES['avatar']['tmp_name'], $user->get('id')."_avatar.jpg", '', $_FILES['avatar']['name']);
				
		}
			
			
		// Get permisson variables from the request
		$permission	= JRequest::getVar( 'permissions', null, 'post', 'array' );		
		
		// Build parameter INI string
		if (is_array($permission))
		{
			$txt = array ();
			foreach ($permission as $k => $v) {
				$txt[] = "$k=$v";
			}
			$author->permission = implode("\n", $txt);
			unset($txt);
		}

		// Get parameter variables from the request
		$params			= JRequest::getVar( 'params', null, 'post', 'array' );		
		
		// Build parameter INI string
		if (is_array($params))
		{
			$txt = array ();
			foreach ($params as $k => $v) {
				$txt[] = "$k=$v";
			}
			$author->attribs = implode("\n", $txt);
			unset($txt);
		}

		// Make sure the data is valid
		if (!$author->check()) {
			$this->setError($author->getError());
			return false;
		}

		// Store it in the db
		if (!$author->store()) {
			$this->setError(500, $this->_db->getErrorMsg() );
			return false;
		}
		
		$this->_author	=& $author;
		
		return true;
	}
}
?>