<?php
/**
 * LyftenBloggie 1.0 - Joomla! Blog Manager
 * @package LyftenBloggie 1.0
 * @copyright (C) 2009 Lyften Designs
 * @license http://www.gnu.org/copyleft/gpl.html GNU/GPL
 * @link http://www.lyften.com/ Official website
 **/
 
// Disallow direct access to this file
defined('_JEXEC') or die('Restricted access');

jimport('joomla.application.component.model');

class LyftenBloggieModelLyftenBloggie extends JModel
{
	var $_data 			= null;
	var $_total 		= null;
	var $_searchby		= null;
	var $_position		= null;
	var $_addThisPubId	= null;
	var $_imageLocation	= null;
	var $_tag			= null;
	var $_category		= null;
	var $_author		= null;

	/**
	 * Constructor
	 **/
	function __construct()
	{
		parent::__construct();

		global $mainframe;
		//set limits
		$params 			= $mainframe->getParams('com_lyftenbloggie');
		$limit 				= $params->get('entrylistLimit');
		$limitstart			= JRequest::getInt('limitstart');
		$this->_tag			= JArrayHelper::getValue( $_REQUEST, 'tag', 0 );
		$this->_category	= JArrayHelper::getValue( $_REQUEST, 'category', 0 );
		$this->_author		= JArrayHelper::getValue( $_REQUEST, 'author', 0 );

		$this->setState('limit', $limit);
		$this->setState('limitstart', $limitstart);		
		
		
		if (JArrayHelper::getValue( $_REQUEST, 'category', '' ) != '') {
				$category = strval(urldecode(JArrayHelper::getValue( $_REQUEST, 'category', '' )));
				$category = str_replace("+", " ", $category);
				$this->_searchby['category'] = $category;
		}

		if (JArrayHelper::getValue( $_REQUEST, 'archive', '' ) != '' ) {
			$archive = urldecode(JArrayHelper::getValue( $_REQUEST, 'archive', '' ));
			$archive = date("Y-m-d", strtotime(str_replace(' ', '-', $archive)));
			$this->_searchby['archive']	= $archive;
		}

	}

	/**
	 * Method to get Data
	 **/
	function getData()
	{
		// Lets load the categories if it doesn't already exist
		if (empty($this->_data))
		{
			$this->_data = $this->_getList( $this->_buildQuery(), $this->getState('limitstart'), $this->getState('limit') );
			$this->_position = 1;
			array_walk($this->_data, array($this, '_prepareEntry') );
		}

		return $this->_data;
	}
	
	/**
	 * Method to build the Categories query
	 **/
	function _buildQuery()
	{
		// Get the WHERE, and ORDER BY clauses for the query
		$tags				= $this->_buildEntriesTags();
		$category			= $this->_buildEntriesCategory();
		$where				= $this->_buildEntriesWhere();
		
		$query = 'SELECT e.*, COUNT(c.entry_id) AS comcount'
				.' FROM #__bloggies_entries AS e'
				.' LEFT JOIN #__bloggies_comments AS c ON c.entry_id = e.id'
				.$tags
				.$category
				.$where
				.' GROUP BY e.created'				
				.' ORDER BY e.created DESC'
				;
		return $query;
	}

	/**
	 * Method to build the where clause of the query
	 **/
	function _buildEntriesCategory()
	{
		return ($this->_category)?' LEFT JOIN #__bloggies_categories AS cat ON cat.slug = '.$this->_db->Quote( $this->_db->getEscaped( $this->_category, true ), false ):'';
	}
	
	/**	
	 * Method to build the where clause of the query
	 **/
	function _buildEntriesTags()
	{
		return ($this->_tag)?' LEFT JOIN #__bloggies_tags AS t ON t.slug = '.$this->_db->Quote( $this->_db->getEscaped( $this->_tag, true ), false ).' LEFT JOIN #__bloggies_relations AS r ON r.tag = t.id':'';
	}
	
	/**
	 * Method to build the where clause of the query
	 **/
	function _buildEntriesWhere()
	{
		global $mainframe, $option;

		$user		= & JFactory::getUser();
		$gid 		= $user->get('aid');
		$authorid 	= isset($this->_searchby['authorid']) 	 ? $this->_db->getEscaped($this->_searchby['authorid']): "";
		$category 	= (isset($this->_searchby['category']) && ($this->_searchby['category'] != strtolower(JText::_('UNCATEGORIZED'))) ) ? $this->_db->getEscaped($this->_searchby['category']): "";
		$search 	= isset($this->_searchby['search']) 	 ? $this->_db->getEscaped($this->_searchby['search']): "";
		$archive 	= isset($this->_searchby['archive']) 	 ? $this->_db->getEscaped($this->_searchby['archive']): "";

		$where[] = 'e.state=1';
		
		$where[] = "e.access <= " . $gid;
		
		if (!empty ($authorid) or $authorid == "0") {
			$where[] = 'e.created_by IN (' . $authorid . ')';
		}

		if (!empty ($search)) {
			$where[] = 'match (e.title,e.fulltext,e.introtext) against (\'' . $search . '\' in BOOLEAN MODE)\'';
		}
		
		if ($this->_tag) {
			$where[] = 'r.entry = e.id';
		}
		
		if ($this->_category) {
			$w = (strtolower($this->_category) == strtolower(JText::_('UNCATEGORIZED')))?'0':'cat.id';
			$where[] = 'e.catid = '.$w;
		}
		
		if ($this->_author) {
			$where[] = 'e.created_by = '.$this->_author;
		}
		
		if (!empty ($archive)) {
			$where[] = 'DATE( e.created ) = ' . $this->_db->Quote( $archive );
		}
		$where 		= ( count( $where ) ? ' WHERE ' . implode( ' AND ', $where ) : '' );

		return $where;
	}
	
	/**
	 * Method to build the Categories query without subselect
	 **/
	function _buildQueryTotal()
	{
		// Get the WHERE,and ORDER BY clauses for the query
		$where		= $this->_buildEntriesWhere();

		$query = 'SELECT count(*)'
				.' FROM #__bloggies_entries as e,'
				.' #__bloggies_permalinks as p'
				.$where
				.' AND e.id=p.entryid'
				;
		return $query;
	}
	
	/**
	 * Total nr of Categories
	 **/
	function getTotal()
	{
		// Lets load the total nr if it doesn't already exist
		if (empty($this->_total))
		{
			$query = $this->_buildQuery();
			$this->_total = $this->_getListCount($query);
		}

		return $this->_total;
	}
	
	function _replaceParams($text, $url, $title, $desc)
	{
		$text = str_replace('***url***', str_replace("'", "", $url), $text);
		$text = str_replace('***url_encoded***', "' + encodeURIComponent('". str_replace("'", "", $url) ."') + '", $text);
		$text = str_replace('***title***', str_replace("'", "", $title), $text);
		$text = str_replace('***title_encoded***', "' + encodeURIComponent('". str_replace("'", "", $title) ."') + '", $text);
		$text = str_replace('***description***', str_replace("'", "", $desc), $text);
		$text = str_replace('***description_encoded***', "' + encodeURIComponent('". str_replace("'", "", $desc) ."') + '", $text);
		$text = str_replace('***imageDirectory***', $this->_imageLocation, $text);
		$text = str_replace('***bgcolor***', '#ffffff', $text);
		$text = str_replace('***addThisPubId***', $this->_addThisPubId, $text);
		
		return $text;
	}
	
	/**
	 * Get the feed data
	 **/
	function getFeed()
	{
		global $mainframe;
		
		$params 	= $mainframe->getParams('com_lyftenbloggie');
		$limit 		= $params->get('entrylistLimit');		
		
		$query = 'SELECT DISTINCT e.*, c.title AS cattitle, COUNT(com.entry_id) AS comcount, u.name as author, '
		. ' CASE WHEN CHAR_LENGTH(e.alias) THEN CONCAT_WS(\':\', e.id, e.alias) ELSE e.id END as slug,'
		. ' CASE WHEN CHAR_LENGTH(c.slug) THEN CONCAT_WS(\':\', c.id, c.slug) ELSE c.id END as catslug'
		. ' FROM #__bloggies_entries AS e'
		. ' LEFT JOIN #__bloggies_categories AS c ON c.id = e.catid'
		. ' LEFT JOIN #__users AS u ON u.id = e.created_by'
		. ' LEFT JOIN #__bloggies_comments AS com ON com.entry_id = e.id'
		. ' WHERE e.state=1'
		. ' GROUP BY e.created'				
		. ' ORDER BY e.created DESC'
		. ' LIMIT '. $limit
		;

		$this->_db->setQuery($query);
		$feed = $this->_db->loadObjectList();

		return $feed;
	}
	
	/**
	 * Get the feed data
	 **/
	function getCategoryInfo()
	{
		if(!$this->_category) return;

		if (strtolower($this->_category) == strtolower(JText::_('UNCATEGORIZED'))) return JText::_('UNCATEGORIZED');
		
		$query = 'SELECT title'
		. ' FROM #__bloggies_categories'
		. ' WHERE slug = '.$this->_db->Quote( $this->_db->getEscaped( $this->_category, true ), false )
		;
		$this->_db->setQuery($query);
		$category = $this->_db->loadResult();
		
		return $category;
	}
	
	/**
	 * Get the feed data
	 **/
	function getTagInfo()
	{
		if(!$this->_tag) return;
		
		$query = 'SELECT name'
		. ' FROM #__bloggies_tags'
		. ' WHERE slug = '.$this->_db->Quote( $this->_db->getEscaped( $this->_tag, true ), false )
		;
		$this->_db->setQuery($query);
		$tag = $this->_db->loadResult();
		return $tag;
	}
	
	/**
	 * Clean up all entries for tge display
	 **/
	function _prepareEntry(&$row, $key){
		global $mainframe;

		// Get the page/component configuration
		$params 		= $mainframe->getParams('com_lyftenbloggie');
		$addThisPubId 	= $params->get('addThisPubId');
		$user			= EntriesHelper::getAuthor();
		$pparams		= new JParameter($row->attribs);
		$dispatcher		= & JDispatcher::getInstance();
	
		// add permalink		
		$row->permalink 	= EntriesHelper::getPermalink($row->title, $row->id);
		
		// Change all relative url to absolute url
		$row->introtext 	= str_replace('src="images', 'src="'. JURI::base() .'/images', $row->introtext);
		$row->fulltext  	= str_replace('src="images', 'src="'. JURI::base() .'/images',  $row->fulltext);
		$created_by			= EntriesHelper::getAuthor($row->created_by);
		$row->author		= $created_by->username;
		$row->category	 	= EntriesHelper::getCatLinks($row->catid, true);
		$row->tags		 	= EntriesHelper::getTagLinks($row->id, true);
		$row->created		= JHTML::_('date',  $row->created, '%B %d, %Y');
		$row->bookmarks		= EntriesHelper::getBookmarks($row->id, $row->title, $row->metadesc, $this->_position, $addThisPubId);
		$row->allowComments	= $pparams->get('allow_comments');

		//check if we have an id(edit) and check if we have global edit rights or if we are allowed to edit own entrys.
		$row->editable = ( ($row->id > 0 && $row->created_by == $user->user_id && $user->permission) || $user->admin);
	
		// Add readmore link if necessary
		$row->readmore	= '1';
		if($params->get('necessaryReadmore') == '1')
		{
			if($row->introtext && empty($row->fulltext) )
			{
				$position = -1;
				$count	  = 0;
				while( ( $position = strpos($row->introtext , '</p>' , $position + 1) ) !== false )
				{
					$count++;
				}

				if( $count <= $params->get('autoReadmorePCount') )
				{
					$row->readmore = '0';
				}
			}
			else
			{
				$position = -1;
				$count	  = 0;
				while( ( $position = strpos($row->fulltext , '</p>' , $position + 1) ) !== false )
				{
					$count++;
				}				
				if( $count <= $params->get('autoReadmorePCount') )
				{
					$row->readmore = '0';
				}
			}
		}
				
		if($params->get('useIntrotext')){
			if(empty($row->fulltext)){
				$ending = strpos($row->introtext, '</p>');
				
				$pos=-1;
				$pos_array = array();
				while (($pos=strpos($row->introtext,'</p>',$pos+1))!==false) 
					$pos_array[]=$pos;
				
				$pNum = $params->get('autoReadmorePCount');
				if (count($pos_array) <= $pNum) {
				   $row->text 		= $row->introtext;
				} else {
					$ending 		= $pos_array[$pNum-1];
					$row->introtext = substr($row->introtext, 0, $ending + 4);
					$row->introtext = EntriesHelper::cleanHTML(preg_replace('#\s*<[^>]+>?\s*$#','',$row->introtext));
				}
			}
			else if( !empty($row->fulltext) && empty($row->introtext) )
			{
				// Strip x paragraphs
				$ending = strpos($row->fulltext, '</p>');
				
				$pos=-1;
				$pos_array = array();
				while (($pos=strpos($row->fulltext,'</p>',$pos+1))!==false) 
				$pos_array[]=$pos;
				
				$pNum = $params->get('autoReadmorePCount');
				if (count($pos_array) <= $pNum) {
					$row->text 		= $row->fulltext;
				} else {
					$ending 		= $pos_array[$pNum-1];
					$row->fulltext 	= substr($row->fulltext, 0, $ending + 4);
					$row->fulltext 	= EntriesHelper::cleanHTML(preg_replace('#\s*<[^>]+>?\s*$#','',$row->fulltext));
				}
			}
			
			$row->text =( empty($row->introtext) )?$row->fulltext:$row->introtext;

		} else{

			$row->text = (empty($row->introtext))?$row->fulltext:$row->introtext;
		}

		// Clean up the final text
		unset($row->fulltext);
		$row->text 	= str_replace(array('{mosimage}', '{mospagebreak}', '{readmore}'), '', $row->text);

		// Process the prepare content plugins
		JPluginHelper::importPlugin('content');
		$results = $dispatcher->trigger('onPrepareContent', array (& $row, & $params, $this->getState('limitstart')));

		// Handle display events
		$row->event = new stdClass();
		$results = $dispatcher->trigger('onAfterDisplayTitle', array ($row, &$params, $this->getState('limitstart')));
		$row->event->afterDisplayTitle = trim(implode("\n", $results));

		$results = $dispatcher->trigger('onBeforeDisplayContent', array (& $row, & $params, $this->getState('limitstart')));
		$row->event->beforeDisplayContent = trim(implode("\n", $results));

		$results = $dispatcher->trigger('onAfterDisplayContent', array (& $row, & $params, $this->getState('limitstart')));
		$row->event->afterDisplayContent = trim(implode("\n", $results));

		$this->_position++;
	}
}
?>